%define name    intel-media
%define version 24.1.3
%define rel     1

%define major   7
%define libname %mklibname igfxcmrt %{major}
%define develname %mklibname igfxcmrt -d

Name:           %{name}
Version:        %{version}
Release:        %mkrel %{rel}
Summary:        Hardware-accelerated video processing on Intel integrated GPUs Library
Group:          System/Kernel and hardware
License:        MIT
URL:            https://github.com/intel/media-driver
Source0:        %{url}/archive/%{name}-%{version}.tar.gz
#

# patches from git upstream
Patch0100:	0001-Decode-Correct-pat-index-setting-for-xe-drm.patch
Patch0101:	0002-Decode-Override-pat-index-for-uptr-bo-binding.patch
Patch0102:	0003-VP-Integrate-3dlut-kernel-support-33-lutsize.patch
Patch0103:	0005-codechal_decode_hevc-avoid-decoding-a-non-intra-fram.patch
Patch0104:	0006-Decode-Fix-memory-access-violation-issue.patch
Patch0105:	0007-Encode-dump-quality-metric-via-umd-profiler.patch
Patch0106:	0008-Encode-va-MBBRC-settings-update-refering-to-VC_RC_MB.patch
Patch0107:	0009-Decode-Fix-AVC-decode-SFC-4K-hang-issue.patch
Patch0108:	0010-Decode-Add-mos-drm-api-to-select-fixed-engine-instan.patch
Patch0109:	0011-Decode-Add-xe-drm-init-entry-for-production-build.patch
Patch0110:	0012-Media-Common-VP-MCPY-Exclude-BCS8-when-creating-BLT-.patch
Patch0111:	0013-Media-Common-VP-Get-pat-index-and-CpuCacheable-from-.patch
Patch0112:	0014-Decode-Add-DeviceIDs-for-ADLN-Refresh.patch
Patch0113:	0015-Revert-VP-Integrate-3dlut-kernel-support-33-lutsize.patch

BuildRequires:  cmake
BuildRequires:  pkgconfig(gmock)
BuildRequires:  pkgconfig(igdgmm) >= 12.3.0
BuildRequires:  pkgconfig(libdrm_intel)
BuildRequires:  pkgconfig(pciaccess)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(ocl-icd)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(libva)

# This package relies on igdgmm which relies on intel asm
ExclusiveArch:  x86_64 

%description
Intel Media SDK provides a plain C API to access hardware-accelerated video
decode, encode and filtering on Intel Gen graphics hardware platforms.
Implementation written in C++ 11 with parts in C-for-Media (CM).

Supported video encoders: HEVC, AVC, MPEG-2, JPEG, VP9 Supported video decoders:
HEVC, AVC, VP8, VP9, MPEG-2, VC1, JPEG Supported video pre-processing filters:
Color Conversion, Deinterlace, Denoise, Resize, Rotate, Composition

%package -n     vaapi-driver-%{name}
Summary:        Hardware-accelerated video processing driver for VAAPI Intel
Group:          System/Kernel and hardware
 
%description -n vaapi-driver-%{name}
This package contains the driver needed to access hardware 
 

%package -n     %{libname}
Summary:        Hardware-accelerated video processing on Intel integrated GPUs Library
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}
 
%description -n %{libname}
This package contains the library needed to run programs dynamically
linked with igfxcmrt library.
 
%package -n     %{develname}
Summary:        SDK for hardware-accelerated video processing on Intel integrated GPUs
Group:          Development/C++
Requires:       %{libname} = %{version}
Provides:       %{name}-devel = %{version}-%{release}
 
%description -n %{develname}
This package contains the headers that programmers will need to develop
applications which will use igfxcmrt library.

%files -n vaapi-driver-%{name}
%{_libdir}/dri/*_drv_video.so
 
%files -n %{libname}
%{_libdir}/libigfxcmrt.so.%{major}{,.*}
 
%files -n %{develname}
%dir %{_includedir}/igfxcmrt
%{_includedir}/igfxcmrt/cm_*.h
%{_libdir}/libigfxcmrt.so
%{_libdir}/pkgconfig/igfxcmrt.pc


%prep
%autosetup -p1 -n media-driver-intel-media-%{version}

%build
%cmake \
    -DBUILD_DISPATCHER=ON \
    -DBUILD_SAMPLES=OFF \
    -DBUILD_TESTS=ON \
    -DBUILD_TOOLS=OFF \
    -DENABLE_OPENCL=ON \
    -DENABLE_WAYLAND=ON \
    -DENABLE_X11=ON \
    -DENABLE_X11_DRI3=ON \
    -DUSE_SYSTEM_GTEST=ON \

%cmake_build

%install
%cmake_install
find %{buildroot} -name '*.la' -exec rm -f {} ';'



%changelog
* Thu Feb 22 2024 ghibo <ghibo> 24.1.3-1.mga10
+ Revision: 2043164
- Update to version 24.1.3.
- Merge patches from git upstream.

* Sat Dec 16 2023 ghibo <ghibo> 23.4.3-1.mga10
+ Revision: 2018325
- Update to version 23.4.3.
- Drop patches merged upstream.

* Tue Sep 19 2023 ghibo <ghibo> 23.3.3-1.mga10
+ Revision: 1988064
- Update to release 23.3.3.
- Merge patches from git upstream.

* Sat Mar 18 2023 ghibo <ghibo> 23.1.3-2.mga9
+ Revision: 1949666
- Merge patch from git upstream to fix a memleak

* Sat Mar 18 2023 ghibo <ghibo> 23.1.3-1.mga9
+ Revision: 1949643
- Update to release 23.1.3.
- Drop patches merged upstream.

* Sat Feb 25 2023 ghibo <ghibo> 23.1.2-1.mga9
+ Revision: 1945394
- Update to release 23.1.2.
- Merge patch from git upstream to fix jpeg decode MD5 mismatch.
- Merge patch from git upstream to fix NULL pointer issue.

* Thu Feb 09 2023 ghibo <ghibo> 23.1.1-1.mga9
+ Revision: 1939727
- Update to release 23.1.1.
- Drop Patch0, merged upstream.
- Versioning igdgmm in BuildRequires.

* Thu Mar 31 2022 kekepower <kekepower> 22.3.0-1.mga9
+ Revision: 1836901
- Add upstream patch to fix build with gcc 12.0.1
- Update to version 22.3.0
- Update to version 22.1.1
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Fri Jul 10 2020 zezinho <zezinho> 20.2.0-1.mga8
+ Revision: 1604322
- new version 20.2.0

* Mon Apr 06 2020 zezinho <zezinho> 19.3.0-2.mga8
+ Revision: 1565321
- fix url

* Mon Apr 06 2020 zezinho <zezinho> 19.3.0-1.mga8
+ Revision: 1565275
- imported package intel-media

